abstract_form/state_management/cubits/_all library

Classes

AbstractFormBusBridgeCubit<S extends AbstractFormBaseState>
A Cubit that bridges form state with an event bus.
AbstractFormBusObserverCubit<S extends AbstractFormBaseState>
A base cubit class for observing events from an event bus. This class extends AbstractFormCubit and listens to a global event bus. Subclasses must implement the observe method to handle incoming events.
AbstractFormBusPublisherCubit<S extends AbstractFormBaseState>
A base cubit class for publishing state changes to an event bus. This class extends AbstractFormCubit and automatically publishes its state changes to a global event bus using attachToEventBus.
AbstractFormCubit<S extends AbstractFormBaseState>
An abstract Cubit for managing form state with support for initialization, validation, submission, and offline fallback.