build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final abstractConfiguration = AbstractConfiguration.of(context);
// Builds the UI layout for displaying the "no data" message
return Center(
child: Column(
mainAxisSize: MainAxisSize.min, // Takes minimum space vertically
crossAxisAlignment:
CrossAxisAlignment.center, // Center-aligns children horizontally
children: [
// Message indicating no data is available
Text(
abstractConfiguration?.translations.thereIsNoData ??
'There is no data',
),
// Space between the message and the reload button
SizedBox(height: 15),
// Reload button to retry fetching data
TextButton(
onPressed: () => onInit?.call(), // Calls onInit if it's not null
child: Text(
abstractConfiguration?.translations.reload ??
'Reload', // Button label
style: TextStyle(color: Colors.black), // Button text color
),
),
// Space below the button
SizedBox(height: 15),
],
),
);
}