abstract_list/state_management/cubits/_all library
Classes
-
AbstractListBusBridgeCubit<
S extends AbstractListState> - An abstract class that acts as a bridge for integrating the cubit with an event bus. It allows the cubit to publish its state and also to listen for events from the event bus.
-
AbstractListBusObserverCubit<
S extends AbstractListState> - An abstract class that allows a cubit to observe events from an event bus. Subclasses must implement logic to handle these events.
-
AbstractListBusPublisherCubit<
S extends AbstractListState> - An abstract class that enables a cubit to publish its state to an event bus. This allows other components to react to state changes outside the cubit.
-
AbstractListCubit<
S extends AbstractListState> - An abstract Cubit for managing list-based state with support for loading, refreshing, pagination, filtering, and caching.