widgets/_all library

Classes

AbstractRefreshIndicator
A lightweight pull-to-refresh indicator that displays a caller-provided icon instead of the Material progress arc used by RefreshIndicator.
AbstractStatefulBuilder
A reusable stateful widget that allows for initialization logic through a builder function and an optional initState callback.
InfoDialog
A customizable information dialog widget.
Loader
The generic loader widget.
LoadInfoIcon
A widget that displays an icon indicating whether loading is occurring or if cached data is available.