child property
The scrollable below the indicator. Must use a scroll physics that reports overscroll (e.g. AlwaysScrollableScrollPhysics or BouncingScrollPhysics) so the pull gesture is detectable when there are few items.
Implementation
final Widget child;