onRefresh property
Called when the user pulls past triggerDistance and releases. The returned future controls how long the spinning state is shown.
Implementation
final Future<void> Function() onRefresh;
Called when the user pulls past triggerDistance and releases. The returned future controls how long the spinning state is shown.
final Future<void> Function() onRefresh;